PrecomputedAlms — so_pysm_models v0.4.dev210

so_pysm_models:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- so_pysm_models v0.4.dev210 »
- PrecomputedAlms

# PrecomputedAlms

class `so_pysm_models.` `PrecomputedAlms`(filename, input_units='uK_CMB', input_reference_frequency_GHz=None, target_nside=None, target_shape=None, target_wcs=None, precompute_output_map=True, has_polarization=True, pixel_indices=None)

  Bases: `object`

  Generic component based on Precomputed Alms

  Load a set of Alms from a FITS file and generate maps at the requested resolution and frequency assuming the CMB black body spectrum. A single set of Alms is used for all frequencies requested by PySM, consider that PySM expects the output of components to be in uK_RJ.

  See more details at https://so-pysm-models.readthedocs.io/en/latest/so_pysm_models/models.html

  Parameters: | filename : string Path to the input Alms in FITS format input_units : string Input unit strings as defined by pysm.convert_units, e.g. K_CMB, uK_RJ, MJysr input_reference_frequency_GHz : float If input units are K_RJ or Jysr, the reference frequency target_nside : int HEALPix NSIDE of the output maps precompute_output_map : bool If True (default), Alms are transformed into a map in the constructor, if False, the object only stores the Alms and generate the map at each call of the signal method, this is useful to generate maps convolved with different beams has_polarization : bool whether or not to simulate also polarization maps Default: True pixel_indices : ndarray of ints Output a partial maps given HEALPix pixel indices in RING ordering

  Methods Summary

  `compute_output_map`(alm) |
  `signal`([nu, fwhm_arcmin, output_units]) | Return map in uK_RJ at given frequency or array of frequencies

  Methods Documentation

  `compute_output_map`(alm)
  `signal`(nu=[148.0], fwhm_arcmin=None, output_units='uK_RJ', **kwargs)

    Return map in uK_RJ at given frequency or array of frequencies

    If nothing is specified for nu, we default to providing an unmodulated map at 148 GHz. The value 148 Ghz does not matter if the output is in uK_RJ.

    Parameters: | nu : list or ndarray Frequency or frequencies in GHz at which compute the signal fwhm_arcmin : float (optional) Smooth the input alms before computing the signal, this can only be used if the class was initialized with `precompute_output_map` to False. output_units : str Output units, as defined in `pysm.convert_units`, by default this is “uK_RJ” as expected by PySM.
    Returns: | output_maps : ndarray Output maps array with the shape (num_freqs, 1 or 3 (I or IQU), npix)